# vivraw

This repository defines a `pip` package, `vivraw`, that contains functions in python to parse the raw plant data generated
by the Vivent PhytlSigns devices.

## Installing the package
This package can be installed directly using `pip` using the following commands:
```
pip install vivraw
```